# API

## pgdumplib

::: pgdumplib
    options:
      show_root_heading: true
      show_source: true

## pgdumplib.dump

::: pgdumplib.dump
    options:
      show_root_heading: true
      show_source: true
